@@ -6,8 +6,8 @@ https://www.aug.ipp.mpg.de/aug/manuals/aug_sfutils
 
 """
 __author__  = 'Giovanni Tardini (Tel. 1898)'
-__version__ = '0.5.1'
-__date__    = '03.11.2021'
+__version__ = '0.5.2'
+__date__    = '05.11.2021'
 
 import os, sys, logging
 
@@ -42,7 +42,7 @@ from .sf2equ import *
 from .libddc import ddcshotnr, previousshot
 from .mapeq import *
 from .getlastshot import getlastshot
-sf_home = os.path.abspath(__file__)
+sf_home = os.path.dirname(os.path.realpath(__file__))
 logger.info('AUG-SF home %s', sf_home)
 
 import encodings.utf_8
