@@ -9,6 +9,18 @@ logger = logging.getLogger('aug_sfutils.manage_ed')
 
 
 def sf_path(nshot, diag, exp='AUGD', ed=0):
+    """Path finder for shotfiles
+
+    Input:
+        nshot    int  Shotnumber
+        diag     str  Diagnostic label
+        exp(opt) str  Expriment label (default: 'AUGD')
+        ed(opt)  int  Edition number (default: 0)
+
+    Output:
+        path_out   str   Full path of shotfile (None if not found)
+        ed         int   Actual edition (non trivial if input ed=0)
+    """
 
     sshot = str(nshot).zfill(5)
     exp = exp.lower()
@@ -43,7 +55,16 @@ def sf_path(nshot, diag, exp='AUGD', ed=0):
 
 
 def ed_zero(diag, nshot, exp='augd'):
+    """Finds the actual edition number of ed=0
+    Input:
+        nshot    int  Shotnumber
+        diag     str  Diagnostic label
+        exp(opt) str  Expriment label (default: 'AUGD')
 
+    Output:
+        ed_nr    int  Actual edition number. 1 for level0, None if not found
+    """
+ 
     sshot = str(nshot).zfill(5)
     exp = exp.lower()
     diag = diag.upper()
@@ -80,7 +101,14 @@ def ed_zero(diag, nshot, exp='augd'):
 
 
 def read_ed_cntl(fed_dir, exp='augd'):
+    """Parser of ed_cntl file
 
+    Input:
+        fed_dir   str   Path where to look for ed_cntl file
+        exp(opt)  str   Exp
+    Output:
+        max_ed    int   Max edition number for given diag, shot
+    """
     ed_ctrl = '%s/ed_cntl' %fed_dir
     if not os.path.isfile(ed_ctrl):
         return None
