@@ -371,10 +371,7 @@ class SFREAD:
                 if j == 0:
                     dout = data*1. # Creates a copy of a read-only array, only once
                     dout.calib = True
-                if (pscal[mult].size > 1):
-                    pscal[mult] = pscal[mult][0]
-                    pscal[shif] = pscal[shif][0]
-                dout *= pscal[mult]
+                dout *= pscal[mult] # it can have size > 1
                 dout += pscal[shif]
             else:
                 break
